#########################
cabalgata-silla-de-montar
#########################
cabalgata 0.1.0

.. image:: https://travis-ci.org/cabalgata/cabalgata-silla-de-montar.svg?branch=master
    :target: https://travis-ci.org/cabalgata/cabalgata-silla-de-montar